@@ -105,10 +105,10 @@ int _gnutls_find_dn(gnutls_datum * odn, gnutls_cert * cert)
 	int start, end;
 
 	if ((result=asn1_create_structure
-	    (_gnutls_get_pkix(), "PKIX1Implicit88.Certificate", &dn,
+	    (_gnutls_get_pkix(), "PKIX1.Certificate", &dn,
 	     "dn")) != ASN_OK) {
 		gnutls_assert();
-		return result;
+		return _gnutls_asn2err(result);
 	}
 
 	result = asn1_get_der(dn, cert->raw.data, cert->raw.size);
@@ -116,7 +116,7 @@ int _gnutls_find_dn(gnutls_datum * odn, gnutls_cert * cert)
 		/* couldn't decode DER */
 		gnutls_assert();
 		asn1_delete_structure(dn);
-		return result;
+		return _gnutls_asn2err(result);
 	}
 
 	result = asn1_get_start_end_der(dn, cert->raw.data, cert->raw.size,
@@ -127,7 +127,7 @@ int _gnutls_find_dn(gnutls_datum * odn, gnutls_cert * cert)
 		/* couldn't decode DER */
 		gnutls_assert();
 		asn1_delete_structure(dn);
-		return result;
+		return _gnutls_asn2err(result);
 	}
 	asn1_delete_structure(dn);
 
@@ -158,7 +158,7 @@ inline
 }
 
 /* Locates the most appropriate x509 certificate using the
- * given DN
+ * given DN. If indx == -1 then no certificate was found.
  */
 static int _find_x509_cert(const GNUTLS_CERTIFICATE_CREDENTIALS cred,
 			   opaque * _data, int _data_size,
@@ -171,11 +171,13 @@ static int _find_x509_cert(const GNUTLS_CERTIFICATE_CREDENTIALS cred,
 	int data_size = _data_size, i, j;
 	int result;
 
+	*indx = -1;
+
 	do {
 
-		DECR_LEN(data_size, 2);
+		DECR_LENGTH_RET(data_size, 2, 0);
 		size = READuint16(data);
-		DECR_LEN(data_size, size);
+		DECR_LENGTH_RET(data_size, size, 0);
 		data += 2;
 
 		for (i = 0; i < cred->ncerts; i++) {
@@ -234,6 +236,8 @@ static int _find_openpgp_cert(const GNUTLS_CERTIFICATE_CREDENTIALS cred,
 {
 	int i, j;
 
+	*indx = -1;
+
 	for (i = 0; i < cred->ncerts; i++) {
 		for (j = 0; j < cred->cert_list_length[i]; j++) {
 
@@ -617,7 +621,7 @@ int _gnutls_gen_cert_server_certificate(GNUTLS_STATE state, opaque ** data)
 /* Process server certificate
  */
 
-#define CLEAR_CERTS for(x=0;x<peer_certificate_list_size;x++) gnutls_free_cert(peer_certificate_list[x])
+#define CLEAR_CERTS for(x=0;x<peer_certificate_list_size;x++) _gnutls_free_cert(peer_certificate_list[x])
 int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 					 int data_size)
 {
@@ -749,7 +753,7 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 	return 0;
 }
 
-#define CLEAR_CERTS for(x=0;x<peer_certificate_list_size;x++) gnutls_free_cert(peer_certificate_list[x])
+#define CLEAR_CERTS for(x=0;x<peer_certificate_list_size;x++) _gnutls_free_cert(peer_certificate_list[x])
 int _gnutls_proc_openpgp_server_certificate(GNUTLS_STATE state,
 					    opaque * data, int data_size)
 {
@@ -1125,10 +1129,10 @@ int _gnutls_proc_cert_client_cert_vrfy(GNUTLS_STATE state, opaque * data,
 				      data_size + HANDSHAKE_HEADER_SIZE)) <
 	    0) {
 		gnutls_assert();
-		gnutls_free_cert(peer_cert);
+		_gnutls_free_cert(peer_cert);
 		return ret;
 	}
-	gnutls_free_cert(peer_cert);
+	_gnutls_free_cert(peer_cert);
 
 	return 0;
 }
