@@ -21,6 +21,9 @@
 /* Functions for operating in an SRP passwd file are included here */
 
 #include "gnutls_int.h"
+
+#ifdef ENABLE_SRP
+
 #include "x509_b64.h"
 #include "gnutls_errors.h"
 #include "auth_srp_passwd.h"
@@ -213,7 +216,7 @@ static int pwd_read_conf( const char* pconf_file, GNUTLS_SRP_PWD_ENTRY* entry, i
 	if (fd==NULL) {
 		gnutls_assert();
 		gnutls_free(entry);
-		return GNUTLS_E_PWD_ERROR;
+		return GNUTLS_E_FILE_ERROR;
 	}
 
 	while( fgets( line, sizeof(line), fd) != NULL) {
@@ -427,3 +430,5 @@ int _gnutls_srp_generate_prime(opaque ** ret_g, opaque ** ret_n, int bits)
 	return 0;
 
 }
+
+#endif /* ENABLE SRP */
