@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.3.92"
+#define LIBGNUTLS_VERSION "0.4.0"
 
 #include <sys/types.h>
 #include <time.h>
@@ -76,6 +76,11 @@ typedef enum GNUTLS_Version { GNUTLS_SSL3=1, GNUTLS_TLS1 } GNUTLS_Version;
 typedef enum GNUTLS_CertificateType { GNUTLS_CRT_X509=1, GNUTLS_CRT_OPENPGP 
 } GNUTLS_CertificateType;
 
+typedef enum GNUTLS_X509_CertificateFmt { GNUTLS_X509_FMT_DER, 
+	GNUTLS_X509_FMT_PEM } GNUTLS_X509_CertificateFmt;
+
+typedef enum GNUTLS_PKAlgorithm { GNUTLS_PK_RSA = 1, GNUTLS_PK_DSA
+} GNUTLS_PKAlgorithm;
 
 /* If you want to change this, then also change the 
  * define in gnutls_int.h, and recompile.
@@ -223,12 +228,16 @@ int gnutls_certificate_allocate_sc( GNUTLS_CERTIFICATE_CREDENTIALS *sc);
 
 int gnutls_certificate_set_dh_params(GNUTLS_CERTIFICATE_CREDENTIALS res, GNUTLS_DH_PARAMS);
 
-int gnutls_certificate_set_x509_trust_file( GNUTLS_CERTIFICATE_CREDENTIALS res, char* CAFILE, char* CRLFILE);
-int gnutls_certificate_set_x509_trust_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const gnutls_datum *CA, const gnutls_datum *CRL);
+int gnutls_certificate_set_x509_trust_file( GNUTLS_CERTIFICATE_CREDENTIALS res, char* CAFILE, 
+	GNUTLS_X509_CertificateFmt);
+int gnutls_certificate_set_x509_trust_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, 
+	const gnutls_datum *CA, GNUTLS_X509_CertificateFmt);
 
-int gnutls_certificate_set_x509_key_file( GNUTLS_CERTIFICATE_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
+int gnutls_certificate_set_x509_key_file( GNUTLS_CERTIFICATE_CREDENTIALS res, 
+	char *CERTFILE, char* KEYFILE, GNUTLS_X509_CertificateFmt);
 int gnutls_certificate_set_x509_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, 
-	const gnutls_datum* CERT, const gnutls_datum* KEY);
+	const gnutls_datum* CERT, const gnutls_datum* KEY,
+	GNUTLS_X509_CertificateFmt);
 
 int gnutls_certificate_set_openpgp_key_file( GNUTLS_CERTIFICATE_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
 int gnutls_certificate_set_openpgp_key_mem( GNUTLS_CERTIFICATE_CREDENTIALS res,
@@ -371,6 +380,8 @@ int gnutls_x509_extract_certificate_serial(const gnutls_datum * cert, char* resu
 time_t gnutls_x509_extract_certificate_activation_time( const gnutls_datum*);
 time_t gnutls_x509_extract_certificate_expiration_time( const gnutls_datum*);
 int gnutls_x509_extract_subject_alt_name( const gnutls_datum*, int seq, char*, int*);
+int gnutls_x509_pkcs7_extract_certificate(const gnutls_datum * pkcs7_struct, int indx, char* certificate, int* certificate_size);
+int gnutls_x509_extract_certificate_pk_algorithm( const gnutls_datum * cert, int* bits);
 
 int gnutls_x509_verify_certificate( const gnutls_datum* cert_list, int cert_list_length, const gnutls_datum * CA_list, int CA_list_length, const gnutls_datum* CRL_list, int CRL_list_length);
 
@@ -379,6 +390,9 @@ int gnutls_openpgp_extract_key_name( const gnutls_datum *cert,
                                  int idx,
                                  gnutls_openpgp_name *dn );
 
+int gnutls_openpgp_extract_key_pk_algorithm(const gnutls_datum *cert,
+                                            int *r_bits);
+
 int gnutls_openpgp_extract_key_version( const gnutls_datum *cert );
 
 time_t gnutls_openpgp_extract_key_creation_time( const gnutls_datum *cert );
@@ -481,6 +495,7 @@ int gnutls_b64_decode_fmt( const gnutls_datum *b64_data, char* result, int* resu
 #define GNUTLS_E_ASN1_DER_OVERFLOW -77
 #define GNUTLS_E_TOO_MANY_EMPTY_PACKETS -78
 #define GNUTLS_E_OPENPGP_UID_REVOKED -79
+#define GNUTLS_E_UNKNOWN_PK_ALGORITHM -80
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
@@ -562,19 +577,19 @@ int gnutls_b64_decode_fmt( const gnutls_datum *b64_data, char* result, int* resu
 
 
 #define ASN_OK                    0
-#define ASN_FILE_NOT_FOUND        GNUTLS_E_FILE_ERROR
-#define ASN_ELEMENT_NOT_FOUND     GNUTLS_E_ASN1_ELEMENT_NOT_FOUND
-#define ASN_IDENTIFIER_NOT_FOUND  GNUTLS_E_ASN1_IDENTIFIER_NOT_FOUND
-#define ASN_DER_ERROR             GNUTLS_E_ASN1_DER_ERROR
-#define ASN_VALUE_NOT_FOUND       GNUTLS_E_ASN1_VALUE_NOT_FOUND
-#define ASN_GENERIC_ERROR         GNUTLS_E_ASN1_GENERIC_ERROR
-#define ASN_VALUE_NOT_VALID       GNUTLS_E_ASN1_VALUE_NOT_VALID
-#define ASN_TAG_ERROR             GNUTLS_E_ASN1_TAG_ERROR
-#define ASN_TAG_IMPLICIT          GNUTLS_E_ASN1_TAG_IMPLICIT
-#define ASN_ERROR_TYPE_ANY        GNUTLS_E_ASN1_TYPE_ANY_ERROR
-#define ASN_SYNTAX_ERROR          GNUTLS_E_ASN1_SYNTAX_ERROR
-#define ASN_MEM_ERROR		  GNUTLS_E_MEMORY_ERROR
-#define ASN_DER_OVERFLOW          GNUTLS_E_ASN1_DER_OVERFLOW
+#define ASN_FILE_NOT_FOUND        1
+#define ASN_ELEMENT_NOT_FOUND     2
+#define ASN_IDENTIFIER_NOT_FOUND  3
+#define ASN_DER_ERROR             4
+#define ASN_VALUE_NOT_FOUND       5
+#define ASN_GENERIC_ERROR         6
+#define ASN_VALUE_NOT_VALID       7
+#define ASN_TAG_ERROR             8
+#define ASN_TAG_IMPLICIT          9
+#define ASN_ERROR_TYPE_ANY        10
+#define ASN_SYNTAX_ERROR          11
+#define ASN_MEM_ERROR		  12
+#define ASN_DER_OVERFLOW          13
 
 
 /******************************************************/
@@ -685,6 +700,9 @@ asn1_read_value(node_asn *root,char *name,unsigned char *value,int *len);
 int
 asn1_create_tree(const static_asn *root,node_asn **pointer);
 
+int 
+asn1_number_of_elements(node_asn *root,char *name,int *num);
+
 #endif
 
 
