@@ -128,7 +128,17 @@ int ret = GNUTLS_E_UNIMPLEMENTED_FEATURE;
 		case GNUTLS_E_ILLEGAL_PARAMETER:
                         ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_ILLEGAL_PARAMETER);
                         break;
-		case GNUTLS_E_ASN1_PARSING_ERROR:
+		case GNUTLS_E_ASN1_ELEMENT_NOT_FOUND:
+		case GNUTLS_E_ASN1_IDENTIFIER_NOT_FOUND:
+		case GNUTLS_E_ASN1_DER_ERROR:
+		case GNUTLS_E_ASN1_VALUE_NOT_FOUND:
+		case GNUTLS_E_ASN1_GENERIC_ERROR:
+		case GNUTLS_E_ASN1_VALUE_NOT_VALID:
+		case GNUTLS_E_ASN1_TAG_ERROR:
+		case GNUTLS_E_ASN1_TAG_IMPLICIT:
+		case GNUTLS_E_ASN1_TYPE_ANY_ERROR:
+		case GNUTLS_E_ASN1_SYNTAX_ERROR:
+		case GNUTLS_E_ASN1_DER_OVERFLOW:
 		case GNUTLS_E_NO_CERTIFICATE_FOUND:
                         ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_BAD_CERTIFICATE);
                         break;
