@@ -291,6 +291,8 @@ typedef struct {
 #define GNUTLS_DHE_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x33 } /* draft-ietf-tls-ciphersuite-05 */
 #define GNUTLS_DHE_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x39 }
 
+#define CIPHER_SUITES_COUNT sizeof(cs_algorithms)/sizeof(gnutls_cipher_suite_entry)-1
+
 static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	/* ANON_DH */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_ARCFOUR_MD5,
@@ -439,16 +441,6 @@ const char *gnutls_mac_get_name( GNUTLS_MACAlgorithm algorithm)
 	return ret;
 }
 
-int _gnutls_mac_count(void)
-{
-	uint8 i, counter = 0;
-	for (i = 0; i < MAX_ALGOS; i++) {
-		if (_gnutls_mac_is_ok(i) == 0)
-			counter++;
-	}
-	return counter;
-}
-
 int _gnutls_mac_is_ok(MACAlgorithm algorithm)
 {
 	size_t ret = -1;
@@ -521,16 +513,6 @@ CompressionMethod _gnutls_compression_get_id(int num)
 	return ret;
 }
 
-int _gnutls_compression_count(void)
-{
-	uint8 i, counter = 0;
-	for (i = 0; i < MAX_ALGOS; i++) {
-		if (_gnutls_compression_is_ok(i) == 0)
-			counter++;
-	}
-	return counter;
-}
-
 int _gnutls_compression_is_ok(CompressionMethod algorithm)
 {
 	size_t ret = -1;
@@ -614,17 +596,6 @@ const char *gnutls_cipher_get_name( GNUTLS_BulkCipherAlgorithm algorithm)
 	return ret;
 }
 
-int _gnutls_cipher_count(void)
-{
-	uint8 i, counter = 0;
-	for (i = 0; i < MAX_ALGOS; i++) {
-		if (_gnutls_cipher_is_ok(i) == 0)
-			counter++;
-	}
-	return counter;
-}
-
-
 int _gnutls_cipher_is_ok(BulkCipherAlgorithm algorithm)
 {
 	size_t ret = -1;
@@ -676,17 +647,6 @@ const char *gnutls_kx_get_name( GNUTLS_KXAlgorithm algorithm)
 	return ret;
 }
 
-int _gnutls_kx_count(void)
-{
-	uint8 i, counter = 0;
-	for (i = 0; i < MAX_ALGOS; i++) {
-		if (_gnutls_kx_is_ok(i) == 0)
-			counter++;
-	}
-	return counter;
-}
-
-
 int _gnutls_kx_is_ok(KXAlgorithm algorithm)
 {
 	size_t ret = -1;
@@ -896,28 +856,6 @@ static int _gnutls_cipher_suite_is_ok(GNUTLS_CipherSuite suite)
 
 }
 
-/* quite expensive */
-int _gnutls_cipher_suite_count(void)
-{
-	GNUTLS_CipherSuite suite;
-	int i, counter = 0, j;
-
-	for (j = 0; j < MAX_CIPHERSUITES; j++) {
-		suite.CipherSuite[0] = j;
-
-		if (j != 0x00 && j != 0xFF)
-			continue;
-
-		for (i = 0; i < MAX_CIPHERSUITES; i++) {
-			suite.CipherSuite[1] = i;
-			if (_gnutls_cipher_suite_is_ok(suite) == 0)
-				counter++;
-		}
-
-	}
-	return counter;
-}
-
 #define SWAP(x, y) memcpy(tmp,x,size); \
 		   memcpy(x,y,size); \
 		   memcpy(y,tmp,size);
@@ -1093,7 +1031,7 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 {
 
 	int i, ret_count, j;
-	int count = _gnutls_cipher_suite_count();
+	int count = CIPHER_SUITES_COUNT;
 	GNUTLS_CipherSuite *tmp_ciphers;
 	GNUTLS_CipherSuite* ciphers;
 	GNUTLS_Version version;
@@ -1118,14 +1056,11 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 	}
 	
 	for (i = 0; i < count; i++) {
-		tmp_ciphers[i].CipherSuite[0] =
-		    cs_algorithms[i].id.CipherSuite[0];
-		tmp_ciphers[i].CipherSuite[1] =
-		    cs_algorithms[i].id.CipherSuite[1];
+		memcpy( &tmp_ciphers[i], &cs_algorithms[i].id, sizeof( GNUTLS_CipherSuite));
 	}
 
 	for (i = j = 0; i < count; i++) {
-		/* remove cipher suites which are not used in the
+		/* remove cipher suites which do not support the
 		 * protocol version used.
 		 */
 		if ( _gnutls_cipher_suite_get_version(tmp_ciphers[i]) > version)
@@ -1146,13 +1081,13 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 		    < 0)
 			continue;
 
-		ciphers[j].CipherSuite[0] = tmp_ciphers[i].CipherSuite[0];
-		ciphers[j].CipherSuite[1] = tmp_ciphers[i].CipherSuite[1];
+		memcpy( &ciphers[j], &tmp_ciphers[i], sizeof( GNUTLS_CipherSuite));
 		j++;
 	}
 
 	ret_count = j;
 
+#if 0 /* expensive */
 	if (ret_count > 0 && ret_count != count) {
 		ciphers =
 		    gnutls_realloc(ciphers,
@@ -1163,6 +1098,11 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 			ciphers = NULL;
 		}
 	}
+#endif
+	if (ret_count == 0) {
+		gnutls_free(ciphers);
+		ciphers = NULL;
+	}
 
 	*_ciphers = ciphers;
 	gnutls_free(tmp_ciphers);
