@@ -5,15 +5,16 @@
 #include <x509_asn1.h>
 #include <gnutls_ui.h>
 
-#define MAX_PARAMS_SIZE 5 /* ok for RSA and DSA */
+#define MAX_PARAMS_SIZE 6 /* ok for RSA and DSA */
 
 /* parameters should not be larger than this limit */
 #define MAX_PARAMETER_SIZE 1200
 #define DSA_PRIVATE_PARAMS 5
 #define DSA_PUBLIC_PARAMS 4
-#define RSA_PARAMS 3
+#define RSA_PRIVATE_PARAMS 6
+#define RSA_PUBLIC_PARAMS 2
 
-#if MAX_PARAMS_SIZE - RSA_PARAMS < 0
+#if MAX_PARAMS_SIZE - RSA_PRIVATE_PARAMS < 0
 # error INCREASE MAX_PARAMS
 #endif
 
@@ -67,6 +68,9 @@ typedef struct {
 				 * RSA: [0] is modulus
 				 *      [1] is public exponent
 				 *	[2] is private exponent
+				 *	[3] is prime1 (p)
+				 *	[4] is prime2 (q)
+				 *	[5] is coefficient (u == inverse of p mod q)
 				 * DSA: [0] is p
 				 *      [1] is q
 				 *      [2] is g
@@ -85,6 +89,6 @@ struct GNUTLS_STATE_INT; /* because GNUTLS_STATE is not defined when this file i
 int _gnutls_cert_supported_kx( const gnutls_cert* cert, KXAlgorithm **alg, int *alg_size);
 PKAlgorithm _gnutls_map_pk_get_pk(KXAlgorithm kx_algorithm);
 
-void gnutls_free_cert(gnutls_cert cert);
+void _gnutls_free_cert(gnutls_cert cert);
 
 #endif
