@@ -135,8 +135,30 @@ int _gnutls_decrypt(GNUTLS_STATE state, char *ciphertext,
 	return ret;
 }
 
+inline
+static GNUTLS_MAC_HANDLE mac_init( MACAlgorithm mac, opaque* secret, int secret_size, int ver) {
+GNUTLS_MAC_HANDLE td;
 
+	if ( ver == GNUTLS_SSL3) { /* SSL 3.0 */
+		td =
+		    _gnutls_mac_init_ssl3( mac, secret,
+		    		secret_size);
+	} else { /* TLS 1 */
+		td =
+		    _gnutls_hmac_init( mac, secret, secret_size);
+	}
 
+	return td;
+}
+
+inline
+static void mac_deinit( GNUTLS_MAC_HANDLE td, opaque* res, int ver) {
+	if ( ver == GNUTLS_SSL3) { /* SSL 3.0 */
+		_gnutls_mac_deinit_ssl3(td, res);
+	} else {
+		_gnutls_hmac_deinit(td, res);
+	}
+}
 
 /* This is the actual encryption 
  * (and also keeps some space for headers (RECORD_HEADER_SIZE) in the 
@@ -169,23 +191,12 @@ int _gnutls_compressed2TLSCiphertext(GNUTLS_STATE state,
 	minor = _gnutls_version_get_minor( ver);
 	major = _gnutls_version_get_major( ver);
 
-	if ( ver == GNUTLS_SSL3) { /* SSL 3.0 */
-		td =
-		    gnutls_mac_init_ssl3(state->security_parameters.
-					  write_mac_algorithm,
-					  state->connection_state.
-					  write_mac_secret.data,
-					  state->connection_state.
-					  write_mac_secret.size);
-	} else { /* TLS 1 */
-		td =
-		    gnutls_hmac_init(state->security_parameters.
-				     write_mac_algorithm,
-				     state->connection_state.
-				     write_mac_secret.data,
-				     state->connection_state.
-				     write_mac_secret.size);
-	}
+
+	/* Initialize MAC */
+	td = mac_init(state->security_parameters.write_mac_algorithm,
+		  state->connection_state.write_mac_secret.data,
+		  state->connection_state.write_mac_secret.size, ver);
+
 	if (td == GNUTLS_MAC_FAILED
 	    && state->security_parameters.write_mac_algorithm != GNUTLS_MAC_NULL) {
 		gnutls_assert();
@@ -197,20 +208,16 @@ int _gnutls_compressed2TLSCiphertext(GNUTLS_STATE state,
 	    CONVuint64(&state->connection_state.write_sequence_number);
 
 	if (td != GNUTLS_MAC_FAILED) {	/* actually when the algorithm in not the NULL one */
-		gnutls_hmac(td, UINT64DATA(seq_num), 8);
+		_gnutls_hmac(td, UINT64DATA(seq_num), 8);
 		
-		gnutls_hmac(td, &type, 1);
+		_gnutls_hmac(td, &type, 1);
 		if ( ver != GNUTLS_SSL3) { /* TLS 1.0 only */
-			gnutls_hmac(td, &major, 1);
-			gnutls_hmac(td, &minor, 1);
-		}
-		gnutls_hmac(td, &c_length, 2);
-		gnutls_hmac(td, compressed.data, compressed.size);
-		if ( ver == GNUTLS_SSL3) { /* SSL 3.0 */
-			gnutls_mac_deinit_ssl3(td, MAC);
-		} else {
-			gnutls_hmac_deinit(td, MAC);
+			_gnutls_hmac(td, &major, 1);
+			_gnutls_hmac(td, &minor, 1);
 		}
+		_gnutls_hmac(td, &c_length, 2);
+		_gnutls_hmac(td, compressed.data, compressed.size);
+		mac_deinit( td, MAC, ver);
 	}
 	switch (_gnutls_cipher_is_block(state->security_parameters.write_bulk_cipher_algorithm)) {
 	case CIPHER_STREAM:
@@ -267,7 +274,7 @@ int _gnutls_compressed2TLSCiphertext(GNUTLS_STATE state,
 	memcpy(&data[headers_size], compressed.data, compressed.size);
 	memcpy(&data[compressed.size+headers_size], MAC, hash_size);
 
-	if ( (ret = gnutls_cipher_encrypt(state->connection_state.
+	if ( (ret = _gnutls_cipher_encrypt(state->connection_state.
 			      write_cipher_state, &data[headers_size], 
 			      length)) < 0) {
 		gnutls_free( data);
@@ -304,33 +311,23 @@ int _gnutls_ciphertext2TLSCompressed(GNUTLS_STATE state,
 	blocksize = _gnutls_cipher_get_block_size(state->security_parameters.
 					  read_bulk_cipher_algorithm);
 
-	if ( ver == GNUTLS_SSL3) {
-		td =
-		    gnutls_mac_init_ssl3(state->security_parameters.
-					  read_mac_algorithm,
-					  state->connection_state.
-					  read_mac_secret.data,
-					  state->connection_state.
-					  read_mac_secret.size);
-	} else {
-		td =
-		    gnutls_hmac_init(state->security_parameters.
-				     read_mac_algorithm,
-				     state->connection_state.
-				     read_mac_secret.data,
-				     state->connection_state.
-				     read_mac_secret.size);
-	}
-
+	/* initialize MAC 
+	 */
+	td = mac_init( state->security_parameters.read_mac_algorithm,
+	  state->connection_state.read_mac_secret.data,
+	  state->connection_state.read_mac_secret.size, ver); 
+	
 	if (td == GNUTLS_MAC_FAILED
 	    && state->security_parameters.read_mac_algorithm != GNUTLS_MAC_NULL) {
 		gnutls_assert();
 		return GNUTLS_E_UNKNOWN_MAC_ALGORITHM;
 	}
 
+	/* actual encryption 
+	 */
 	switch (_gnutls_cipher_is_block(state->security_parameters.read_bulk_cipher_algorithm)) {
 	case CIPHER_STREAM:
-		if ( (ret = gnutls_cipher_decrypt(state->connection_state.
+		if ( (ret = _gnutls_cipher_decrypt(state->connection_state.
 			      read_cipher_state, ciphertext.data,
 			      ciphertext.size)) < 0) {
 			gnutls_assert();
@@ -348,7 +345,7 @@ int _gnutls_ciphertext2TLSCompressed(GNUTLS_STATE state,
 			return GNUTLS_E_DECRYPTION_FAILED;
 		}
 
-		if ( (ret = gnutls_cipher_decrypt(state->connection_state.
+		if ( (ret = _gnutls_cipher_decrypt(state->connection_state.
 			      read_cipher_state, ciphertext.data,
 			      ciphertext.size)) < 0) {
 			gnutls_assert();
@@ -400,25 +397,23 @@ int _gnutls_ciphertext2TLSCompressed(GNUTLS_STATE state,
 	seq_num = CONVuint64( &state->connection_state.read_sequence_number);
 
 	if (td != GNUTLS_MAC_FAILED) {
-		gnutls_hmac(td, UINT64DATA(seq_num), 8);
+		_gnutls_hmac(td, UINT64DATA(seq_num), 8);
 		
-		gnutls_hmac(td, &type, 1);
+		_gnutls_hmac(td, &type, 1);
 		if ( ver != GNUTLS_SSL3) { /* TLS 1.0 only */
-			gnutls_hmac(td, &major, 1);
-			gnutls_hmac(td, &minor, 1);
+			_gnutls_hmac(td, &major, 1);
+			_gnutls_hmac(td, &minor, 1);
 		}
-		gnutls_hmac(td, &c_length, 2);
+		_gnutls_hmac(td, &c_length, 2);
 		
 		if (data!=NULL)
-			gnutls_hmac(td, data, compress->size);
+			_gnutls_hmac(td, data, compress->size);
 
-		if ( ver == GNUTLS_SSL3) { /* SSL 3.0 */
-			gnutls_mac_deinit_ssl3(td, MAC);
-		} else {
-			gnutls_hmac_deinit(td, MAC);
-		}
+		mac_deinit( td, MAC, ver);
 	}
-	/* HMAC was not the same. */
+
+	/* HMAC was not the same. 
+	 */
 	if (memcmp
 	    (MAC, &ciphertext.data[compress->size], hash_size) != 0) {
 		gnutls_free( data);
