@@ -88,6 +88,8 @@ int gnutls_x509_extract_certificate_serial(const gnutls_datum * cert, char* resu
 time_t gnutls_x509_extract_certificate_activation_time( const gnutls_datum*);
 time_t gnutls_x509_extract_certificate_expiration_time( const gnutls_datum*);
 int gnutls_x509_extract_subject_alt_name( const gnutls_datum*, int seq, char*, int*);
+int gnutls_x509_pkcs7_extract_certificate(const gnutls_datum * pkcs7_struct, int indx, char* certificate, int* certificate_size);
+int gnutls_x509_extract_certificate_pk_algorithm( const gnutls_datum * cert, int* bits);
 
 int gnutls_x509_verify_certificate( const gnutls_datum* cert_list, int cert_list_length, const gnutls_datum * CA_list, int CA_list_length, const gnutls_datum* CRL_list, int CRL_list_length);
 
@@ -96,6 +98,9 @@ int gnutls_openpgp_extract_key_name( const gnutls_datum *cert,
                                  int idx,
                                  gnutls_openpgp_name *dn );
 
+int gnutls_openpgp_extract_key_pk_algorithm(const gnutls_datum *cert,
+                                            int *r_bits);
+
 int gnutls_openpgp_extract_key_version( const gnutls_datum *cert );
 
 time_t gnutls_openpgp_extract_key_creation_time( const gnutls_datum *cert );
