@@ -2,17 +2,8 @@
 #include "x509_asn1.h"
 
 const static_asn pkix_asn1_tab[]={
-  {"PKIX1Implicit88",536875024,0},
-  {0,1610612748,0},
-  {"iso",1073741825,"1"},
-  {"identified-organization",1073741825,"3"},
-  {"dod",1073741825,"6"},
-  {"internet",1073741825,"1"},
-  {"security",1073741825,"5"},
-  {"mechanisms",1073741825,"5"},
-  {"pkix",1073741825,"7"},
-  {"id-mod",1073741825,"0"},
-  {"id-pkix1-implicit-88",1,"2"},
+  {"PKIX1",536875024,0},
+  {0,1073741836,0},
   {"id-ce",1879048204,0},
   {"joint-iso-ccitt",1073741825,"2"},
   {"ds",1073741825,"5"},
@@ -869,6 +860,42 @@ const static_asn pkix_asn1_tab[]={
   {"ub-surname-length",1342177283,"40"},
   {"ub-terminal-id-length",1342177283,"24"},
   {"ub-unformatted-address-length",1342177283,"180"},
-  {"ub-x121-address-length",268435459,"16"},
+  {"ub-x121-address-length",1342177283,"16"},
+  {"ContentInfo",1610612741,0},
+  {"contentType",1073741826,"ContentType"},
+  {"content",541073421,0},
+  {0,1073743880,"0"},
+  {"contentType",1,0},
+  {"ContentType",1073741836,0},
+  {"SignedData",1610612741,0},
+  {"version",1073741826,"CMSVersion"},
+  {"digestAlgorithms",1073741826,"DigestAlgorithmIdentifiers"},
+  {"encapContentInfo",1073741826,"EncapsulatedContentInfo"},
+  {"certificates",1610637314,"CertificateSet"},
+  {0,4104,"0"},
+  {"crls",1610637314,"CertificateRevocationLists"},
+  {0,4104,"1"},
+  {"signerInfos",2,"SignerInfos"},
+  {"CMSVersion",1610874883,0},
+  {"v0",1073741825,"0"},
+  {"v1",1073741825,"1"},
+  {"v2",1073741825,"2"},
+  {"v3",1073741825,"3"},
+  {"v4",1,"4"},
+  {"DigestAlgorithmIdentifiers",1610612751,0},
+  {0,2,"DigestAlgorithmIdentifier"},
+  {"DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
+  {"EncapsulatedContentInfo",1610612741,0},
+  {"eContentType",1073741826,"ContentType"},
+  {"eContent",536895495,0},
+  {0,2056,"0"},
+  {"CertificateRevocationLists",1610612751,0},
+  {0,2,"CertificateList"},
+  {"CertificateChoices",1610612754,0},
+  {"certificate",2,"Certificate"},
+  {"CertificateSet",1610612751,0},
+  {0,2,"CertificateChoices"},
+  {"SignerInfos",536870927,0},
+  {0,13,0},
   {0,0,0}
 };
