@@ -42,7 +42,7 @@ opaque *str;
 int result, len;
 int start, end;
 
-	if (asn1_create_structure( _gnutls_get_pkix(), "PKIX1Implicit88.Certificate", &c2, "certificate")!=ASN_OK) {
+	if (asn1_create_structure( _gnutls_get_pkix(), "PKIX1.Certificate", &c2, "certificate")!=ASN_OK) {
 		gnutls_assert();
 		return ret;
 	}
@@ -85,14 +85,14 @@ int len;
 
 	if ((result=asn1_create_structure( _gnutls_get_gnutls_asn(), "GNUTLS.DigestInfo", &dinfo, "digest_info"))!=ASN_OK) {
 		gnutls_assert();
-		return result;
+		return _gnutls_asn2err(result);
 	}
 
 	result = asn1_get_der( dinfo, info->data, info->size);
 	if (result != ASN_OK) {
 		gnutls_assert();
 		asn1_delete_structure(dinfo);
-		return result;
+		return _gnutls_asn2err(result);
 	}
 	
 	len = sizeof(str)-1;
@@ -101,7 +101,7 @@ int len;
 	if (result != ASN_OK) {
 		gnutls_assert();
 		asn1_delete_structure(dinfo);
-		return result;
+		return _gnutls_asn2err(result);
 	}
 
 	*hash = -1;
@@ -126,7 +126,7 @@ int len;
 	if (result != ASN_OK) {
 		gnutls_assert();
 		asn1_delete_structure(dinfo);
-		return result;
+		return _gnutls_asn2err(result);
 	}
 
 	asn1_delete_structure(dinfo);
@@ -140,7 +140,7 @@ int len;
  * params[1] is public key
  */
 static int
-_pkcs1_rsa_verify_sig( const gnutls_datum* signature, gnutls_datum* text, MPI *params)
+_pkcs1_rsa_verify_sig( const gnutls_datum* signature, gnutls_datum* text, MPI *params, int params_len)
 {
 	MACAlgorithm hash;
 	int ret;
@@ -149,7 +149,7 @@ _pkcs1_rsa_verify_sig( const gnutls_datum* signature, gnutls_datum* text, MPI *p
 	GNUTLS_HASH_HANDLE hd;
 	gnutls_datum decrypted;
 	
-	if ( (ret=_gnutls_pkcs1_rsa_decrypt( &decrypted, *signature, params, 1)) < 0) {
+	if ( (ret=_gnutls_pkcs1_rsa_decrypt( &decrypted, *signature, params, params_len, 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -166,14 +166,14 @@ _pkcs1_rsa_verify_sig( const gnutls_datum* signature, gnutls_datum* text, MPI *p
 
 	gnutls_sfree_datum( &decrypted);
 
-	if (digest_size != gnutls_hash_get_algo_len(hash)) {
+	if (digest_size != _gnutls_hash_get_algo_len(hash)) {
 		gnutls_assert();
 		return GNUTLS_E_ASN1_GENERIC_ERROR;
 	}
 
-	hd = gnutls_hash_init( hash);
-	gnutls_hash( hd, text->data, text->size);
-	gnutls_hash_deinit( hd, md);
+	hd = _gnutls_hash_init( hash);
+	_gnutls_hash( hd, text->data, text->size);
+	_gnutls_hash_deinit( hd, md);
 
 	if (memcmp( md, digest, digest_size)!=0) {
 		gnutls_assert();
@@ -205,7 +205,7 @@ gnutls_datum tbs;
 	switch( issuer->subject_pk_algorithm) {
 		case GNUTLS_PK_RSA:
 		
-			if (_pkcs1_rsa_verify_sig( &signature, &tbs, issuer->params)!=0) {
+			if (_pkcs1_rsa_verify_sig( &signature, &tbs, issuer->params, issuer->params_size)!=0) {
 				gnutls_assert();
 				gnutls_free_datum( &tbs);
 				return GNUTLS_CERT_INVALID;
@@ -216,7 +216,7 @@ gnutls_datum tbs;
 			break;
 
 		case GNUTLS_PK_DSA:
-			if (_gnutls_dsa_verify( &tbs, &signature, issuer->params)!=0) {
+			if (_gnutls_dsa_verify( &tbs, &signature, issuer->params, issuer->params_size)!=0) {
 				gnutls_assert();
 				gnutls_free_datum( &tbs);
 				return GNUTLS_CERT_INVALID;
