@@ -53,6 +53,7 @@ char *hostname = NULL;
 int port;
 int record_max_size;
 int fingerprint;
+int crlf;
 
 char *srp_passwd;
 char *srp_username;
@@ -64,6 +65,7 @@ char *x509_keyfile;
 char *x509_certfile;
 char *x509_cafile;
 char *x509_crlfile = NULL;
+static int x509ctype;
 
 
 int protocol_priority[16] = { GNUTLS_TLS1, GNUTLS_SSL3, 0 };
@@ -160,13 +162,6 @@ int main(int argc, char **argv)
       exit(1);
    }
 
-   printf("Resolving '%s'...\n", hostname);
-   /* get server name */
-   server_host = gethostbyname(hostname);
-   if (server_host == NULL) {
-      fprintf(stderr, "Cannot resolve %s\n", hostname);
-      exit(1);
-   }
 
    /* X509 stuff */
    if (gnutls_certificate_allocate_sc(&xcred) < 0) {	/* space for 2 certificates */
@@ -177,16 +172,18 @@ int main(int argc, char **argv)
    if (x509_cafile != NULL) {
       ret =
 	  gnutls_certificate_set_x509_trust_file(xcred, x509_cafile,
-						 x509_crlfile);
+					 x509ctype);
       if (ret < 0) {
 	 fprintf(stderr, "Error setting the x509 trust file\n");
+      } else {
+      	 printf("Processed %d CA certificate(s).\n", ret);
       }
    }
 
    if (x509_certfile != NULL) {
       ret =
 	  gnutls_certificate_set_x509_key_file(xcred, x509_certfile,
-					       x509_keyfile);
+				       x509_keyfile, x509ctype);
       if (ret < 0) {
 	 fprintf(stderr, "Error setting the x509 key files ('%s', '%s')\n",
 		 x509_certfile, x509_keyfile);
@@ -231,6 +228,14 @@ int main(int argc, char **argv)
       exit(1);
    }
 
+   printf("Resolving '%s'...\n", hostname);
+   /* get server name */
+   server_host = gethostbyname(hostname);
+   if (server_host == NULL) {
+      fprintf(stderr, "Cannot resolve %s\n", hostname);
+      exit(1);
+   }
+
    sd = socket(AF_INET, SOCK_STREAM, 0);
    ERR(sd, "socket");
 
@@ -435,6 +440,12 @@ int main(int argc, char **argv)
 	    continue;
 	 }
 	 do {
+	    if ( crlf != 0) {
+	        char* b=strchr( buffer, '\n');
+	        if (b!=NULL)
+		    	strcpy( b, "\r\n");
+	    }
+	    	
 	    ret = gnutls_record_send(state, buffer, strlen(buffer));
 	 } while (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED);
 	 if (ret > 0)
@@ -482,6 +493,11 @@ void gaa_parser(int argc, char **argv)
    record_max_size = info.record_size;
    fingerprint = info.fingerprint;
 
+   if (info.fmtder == 0)
+      x509ctype = GNUTLS_X509_FMT_PEM;
+   else
+      x509ctype = GNUTLS_X509_FMT_DER;
+
 #ifdef DEBUG
    if (info.x509_certfile != NULL)
       x509_certfile = info.x509_certfile;
@@ -520,7 +536,7 @@ void gaa_parser(int argc, char **argv)
 #else
       srp_username = info.srp_username;
       srp_passwd = info.srp_passwd;
-      x509_cafile = info.x509_certfile;
+      x509_cafile = info.x509_cafile;
       x509_keyfile = info.x509_keyfile;
       x509_certfile = info.x509_certfile;
       pgp_keyfile = info.pgp_keyfile;
@@ -530,6 +546,8 @@ void gaa_parser(int argc, char **argv)
 
    pgp_keyring = info.pgp_keyring;
    pgp_trustdb = info.pgp_trustdb;
+   
+   crlf = info.crlf;
 
    if (info.nrest_args == 0)
       hostname = "localhost";
